@@ -7,7 +7,6 @@
  */
 
 #include "addlocationmodel.h"
-#include "about.h"
 #include "alarm.h"
 #include "alarmmodel.h"
 #include "kclockformat.h"
@@ -63,7 +62,7 @@ int main(int argc, char *argv[])
     KAboutData aboutData(QStringLiteral("kclock"),
                          QStringLiteral("Clock"),
                          QStringLiteral(KCLOCK_VERSION_STRING),
-                         QStringLiteral("Set alarms and timers, use a stopwatch, and manage world clocks"),
+                         i18n("Set alarms and timers, use a stopwatch, and manage world clocks"),
                          KAboutLicense::GPL,
                          i18n("© 2020-2022 KDE Community"));
     aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=KClock");
@@ -108,28 +107,27 @@ int main(int argc, char *argv[])
     qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerPresetModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return TimerPresetModel::instance();
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<TimerModel>("kclock", 1, 0, "TimerModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return TimerModel::instance();
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "AlarmModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<AlarmModel>("kclock", 1, 0, "AlarmModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return AlarmModel::instance();
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "UtilModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<UtilModel>("kclock", 1, 0, "UtilModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return UtilModel::instance();
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "StopwatchTimer", [stopwatchTimer](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<StopwatchTimer>("kclock", 1, 0, "StopwatchTimer", [stopwatchTimer](QQmlEngine *, QJSEngine *) -> QObject * {
         return stopwatchTimer;
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "KClockFormat", [](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<KclockFormat>("kclock", 1, 0, "KClockFormat", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return KclockFormat::instance();
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "WeekModel", [weekModel](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<WeekModel>("kclock", 1, 0, "WeekModel", [weekModel](QQmlEngine *, QJSEngine *) -> QObject * {
         return weekModel;
     });
-    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "SettingsModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<SettingsModel>("kclock", 1, 0, "SettingsModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return SettingsModel::instance();
     });
-    qmlRegisterSingletonInstance("kclock", 1, 0, "AboutType", &AboutType::instance());
 
     QQmlApplicationEngine *engine = new QQmlApplicationEngine();
 
