@@ -14,9 +14,11 @@ class UtilModel : public QObject
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString tzName READ getCurrentTimeZoneName NOTIFY propertyChanged)
+    Q_PROPERTY(QString tzName READ getCurrentTimeZoneName CONSTANT)
+    Q_PROPERTY(bool use24HourTime READ use24HourTime NOTIFY use24HourTimeChanged)
 
 public:
+    UtilModel(QObject *parent = nullptr);
     static UtilModel *instance();
 
     Q_INVOKABLE QString getDefaultAlarmFileLocation();
@@ -26,17 +28,12 @@ public:
     long long calculateNextRingTime(int hours, int minutes, int daysOfWeek, int snooze = 0);
     QString timeToRingFormatted(const long long &timestamp);
 
-    QString timeFormat();
-    bool use24HourTime();
+    QString timeFormat() const;
+    bool use24HourTime() const;
 
 private:
-    UtilModel(){}; // explicitly declare it private
-
-    bool isLocale24HourTime();
-
-    bool m_applicationLoaded = false;
+    bool isLocale24HourTime() const;
 
 Q_SIGNALS:
-    void propertyChanged();
-    void applicationLoadedChanged();
+    void use24HourTimeChanged();
 };
