@@ -101,8 +101,8 @@ KClock_KWeather_3x3::KClock_KWeather_3x3(QObject *parent, const QVariantList &ar
         auto alarmTime = KClock_reply.value();
         if (alarmTime > 0) {
             auto dateTime = QDateTime::fromSecsSinceEpoch(alarmTime).toLocalTime();
-            m_string =
-                m_local.standaloneDayName(dateTime.date().dayOfWeek(), QLocale::ShortFormat) + " " + m_local.toString(dateTime.time(), QStringLiteral("hh:mm"));
+            m_string = QStringLiteral("%1 %2").arg(m_local.standaloneDayName(dateTime.date().dayOfWeek(), QLocale::ShortFormat),
+                                                   m_local.toString(dateTime.time(), QStringLiteral("hh:mm")));
             m_hasAlarm = true;
         } else
             m_hasAlarm = false;
@@ -134,8 +134,8 @@ void KClock_KWeather_3x3::updateAlarm(qulonglong time)
 {
     auto dateTime = QDateTime::fromSecsSinceEpoch(time).toLocalTime();
     if (time > 0) {
-        m_string = m_local.standaloneDayName(dateTime.date().dayOfWeek(), QLocale::ShortFormat) + QStringLiteral(" ")
-            + m_local.toString(dateTime.time(), QStringLiteral("hh:mm"));
+        m_string = QStringLiteral("%1 %2").arg(m_local.standaloneDayName(dateTime.date().dayOfWeek(), QLocale::ShortFormat),
+                                               m_local.toString(dateTime.time(), QStringLiteral("hh:mm")));
         m_hasAlarm = true;
     } else {
         m_hasAlarm = false;
